==> openshift-model-tuned-5.12.1-sources.jar: io/fabric8/openshift/api/model/tuned/v1/ProfileBuilder.java <==
package io.fabric8.openshift.api.model.tuned.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ProfileBuilder extends io.fabric8.openshift.api.model.tuned.v1.ProfileFluentImpl<io.fabric8.openshift.api.model.tuned.v1.ProfileBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.tuned.v1.Profile,io.fabric8.openshift.api.model.tuned.v1.ProfileBuilder>{
  public ProfileBuilder() {
    this(false);
  }
  public ProfileBuilder(java.lang.Boolean validationEnabled) {
    this(new Profile(), validationEnabled);
  }
  public ProfileBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileFluent<?> fluent) {
    this(fluent, false);
  }
  public ProfileBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Profile(), validationEnabled);
  }
  public ProfileBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileFluent<?> fluent,io.fabric8.openshift.api.model.tuned.v1.Profile instance) {
    this(fluent, instance, false);
  }
  public ProfileBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileFluent<?> fluent,io.fabric8.openshift.api.model.tuned.v1.Profile instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProfileBuilder(io.fabric8.openshift.api.model.tuned.v1.Profile instance) {
    this(instance,false);
  }
  public ProfileBuilder(io.fabric8.openshift.api.model.tuned.v1.Profile instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.tuned.v1.ProfileFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.tuned.v1.Profile build() {
    Profile buildable = new Profile(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProfileBuilder that = (ProfileBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-tuned-6.5.1-sources.jar: io/fabric8/openshift/api/model/tuned/v1/ProfileBuilder.java <==
package io.fabric8.openshift.api.model.tuned.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ProfileBuilder extends ProfileFluentImpl<ProfileBuilder> implements VisitableBuilder<Profile,ProfileBuilder>{
  public ProfileBuilder() {
    this(false);
  }
  public ProfileBuilder(Boolean validationEnabled) {
    this(new Profile(), validationEnabled);
  }
  public ProfileBuilder(ProfileFluent<?> fluent) {
    this(fluent, false);
  }
  public ProfileBuilder(ProfileFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Profile(), validationEnabled);
  }
  public ProfileBuilder(ProfileFluent<?> fluent,Profile instance) {
    this(fluent, instance, false);
  }
  public ProfileBuilder(ProfileFluent<?> fluent,Profile instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProfileBuilder(Profile instance) {
    this(instance,false);
  }
  public ProfileBuilder(Profile instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ProfileFluent<?> fluent;
  Boolean validationEnabled;
  public Profile build() {
    Profile buildable = new Profile(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
